@@ -1,27 +1,21 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-from ..benchmarks import Benchmarks
-from . import Command
-from ..repo import get_repo
-from .setup import Setup
-from ..console import log
-
-from . import common_args
 from .. import environment
+from ..benchmarks import Benchmarks
+from ..repo import get_repo
+from . import Command, common_args
 
 
 class Check(Command):
     @classmethod
     def setup_arguments(cls, subparsers):
         parser = subparsers.add_parser(
-            "check", help="Import and check benchmark suite, but do not run benchmarks.",
+            "check",
+            help="Import and check benchmark suite, but do not run benchmarks",
             description="""
                 This imports and checks basic validity of the benchmark suite, but
-                does not run the benchmark target code.""")
+                does not run the benchmark target code""",
+        )
 
         common_args.add_environment(parser, default_same=False)
         parser.set_defaults(func=cls.run_from_args)
@@ -43,6 +37,5 @@ class Check(Command):
         repo = get_repo(conf)
 
         commit_hashes = []  # use fallback defaults
-        benchmarks = Benchmarks.discover(conf, repo, environments, commit_hashes,
-                                         check=True)
+        Benchmarks.discover(conf, repo, environments, commit_hashes, check=True)
         return 0
