@@ -1,27 +1,21 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, division, unicode_literals, print_function
-
-from distutils.version import LooseVersion
-import sys
-import re
 import os
+import re
+import sys
 
-import six
+from packaging.version import Version
 
-from .. import environment
+from .. import environment, util
 from ..console import log
-from .. import util
 
-
-WIN = (os.name == "nt")
+WIN = os.name == "nt"
 
 
 class Virtualenv(environment.Environment):
     """
     Manage an environment using virtualenv.
     """
+
     tool_name = "virtualenv"
 
     def __init__(self, conf, python, requirements, tagged_env_vars):
@@ -42,22 +36,17 @@ class Virtualenv(environment.Environment):
         """
         executable = Virtualenv._find_python(python)
         if executable is None:
-            raise environment.EnvironmentUnavailable(
-                "No executable found for python {0}".format(python))
+            raise environment.EnvironmentUnavailable(f"No executable found for python {python}")
 
         self._executable = executable
         self._python = python
         self._requirements = requirements
-        super(Virtualenv, self).__init__(conf,
-                                         python,
-                                         requirements,
-                                         tagged_env_vars)
+        super().__init__(conf, python, requirements, tagged_env_vars)
 
         try:
-            import virtualenv
+            import virtualenv  # noqa: F401 unused, but required to test whether virtualenv is installed or not
         except ImportError:
-            raise environment.EnvironmentUnavailable(
-                "virtualenv package not installed")
+            raise environment.EnvironmentUnavailable("virtualenv package not installed")
 
     @staticmethod
     def _find_python(python):
@@ -73,18 +62,20 @@ class Virtualenv(environment.Environment):
                 python_version = python[4:]
         else:
             python_version = python
-            executable = "python{0}".format(python_version)
+            executable = f"python{python_version}"
 
         # Find Python executable on path
         try:
             return util.which(executable)
-        except IOError:
+        except OSError:
             pass
 
         # Maybe the current one is correct?
         current_is_pypy = hasattr(sys, 'pypy_version_info')
-        current_versions = ['{0[0]}'.format(sys.version_info),
-                            '{0[0]}.{0[1]}'.format(sys.version_info)]
+        current_versions = [
+            f'{sys.version_info[0]}',
+            f'{sys.version_info[0]}.{sys.version_info[1]}',
+        ]
 
         if is_pypy == current_is_pypy and python_version in current_versions:
             return sys.executable
@@ -100,10 +91,9 @@ class Virtualenv(environment.Environment):
         if self._python.startswith('pypy'):
             # get_env_name adds py-prefix
             python = python[2:]
-        return environment.get_env_name(self.tool_name,
-                                        python,
-                                        self._requirements,
-                                        self._tagged_env_vars)
+        return environment.get_env_name(
+            self.tool_name, python, self._requirements, self._tagged_env_vars
+        )
 
     @classmethod
     def matches(self, python):
@@ -116,13 +106,12 @@ class Virtualenv(environment.Environment):
         except ImportError:
             return False
         else:
-            if LooseVersion(virtualenv.__version__) == LooseVersion('1.11.0'):
+            if Version(virtualenv.__version__) == Version('1.11.0'):
                 log.warning(
-                    "asv is not compatible with virtualenv 1.11 due to a bug in "
-                    "setuptools.")
-            if LooseVersion(virtualenv.__version__) < LooseVersion('1.10'):
-                log.warning(
-                    "If using virtualenv, it much be at least version 1.10")
+                    "asv is not compatible with virtualenv 1.11 due to a bug in setuptools."
+                )
+            if Version(virtualenv.__version__) < Version('1.10'):
+                log.warning("If using virtualenv, it much be at least version 1.10")
 
         executable = Virtualenv._find_python(python)
         return executable is not None
@@ -136,46 +125,58 @@ class Virtualenv(environment.Environment):
         env = dict(os.environ)
         env.update(self.build_env_vars)
 
-        log.info("Creating virtualenv for {0}".format(self.name))
-        util.check_call([
-            sys.executable,
-            "-mvirtualenv",
-            "-p",
-            self._executable,
-            self._path], env=env)
+        # NOTE: Omit `--wheel=bundle` for virtualenv v20.31 and later.
+        # See https://github.com/airspeed-velocity/asv/issues/1484 and https://github.com/pypa/virtualenv/pull/2868
+        # TODO: Remove this check and the `--wheel=bundle` option altogether
+        # once asv supports at minimum Python >= 3.8 and virtualenv >= 20.31.
+        import virtualenv
 
-        log.info("Installing requirements for {0}".format(self.name))
+        use_wheel = Version(virtualenv.__version__) < Version('20.31')
+
+        log.info(f"Creating virtualenv for {self.name}")
+        util.check_call(
+            [
+                sys.executable,
+                "-m",
+                "virtualenv",
+                *(["--wheel=bundle"] if use_wheel else []),
+                "--setuptools=bundle",
+                "-p",
+                self._executable,
+                self._path,
+            ],
+            env=env,
+        )
+
+        log.info(f"Installing requirements for {self.name}")
         self._install_requirements()
 
     def _install_requirements(self):
-        if sys.version_info[:2] == (3, 2):
-            pip_args = ['install', '-v', 'wheel<0.29.0', 'pip<8']
-        else:
-            pip_args = ['install', '-v', 'wheel', 'pip>=8']
+        pip_args = ['install', '-v', 'wheel', 'pip>=8']
 
         env = dict(os.environ)
         env.update(self.build_env_vars)
 
         self._run_pip(pip_args, env=env)
+        pip_args = []
 
-        if self._requirements:
-            args = ['install', '-v', '--upgrade']
-            for key, val in six.iteritems(self._requirements):
-                pkg = key
-                if key.startswith('pip+'):
-                    pkg = key[4:]
+        for key, val in {**self._requirements, **self._base_requirements}.items():
+            if key.startswith("pip+"):
+                pip_args.append(f"{key[4:]} {val}")
+            else:
+                pip_args.append(f"{key} {val}")
 
-                if val:
-                    args.append("{0}=={1}".format(pkg, val))
-                else:
-                    args.append(pkg)
-            self._run_pip(args, timeout=self._install_timeout, env=env)
+        for declaration in pip_args:
+            parsed_declaration = util.ParsedPipDeclaration(declaration)
+            pip_call = util.construct_pip_call(self._run_pip, parsed_declaration)
+            pip_call()
 
     def _run_pip(self, args, **kwargs):
         # Run pip via python -m pip, so that it works on Windows when
         # upgrading pip itself, and avoids shebang length limit on Linux
-        return self.run_executable('python', ['-mpip'] + list(args), **kwargs)
+        return self.run_executable('python', ['-m', 'pip'] + list(args), **kwargs)
 
     def run(self, args, **kwargs):
-        log.debug("Running '{0}' in {1}".format(' '.join(args), self.name))
+        joined_args = ' '.join(args)
+        log.debug(f"Running '{joined_args}' in {self.name}")
         return self.run_executable('python', args, **kwargs)
