@@ -14,10 +14,10 @@ def test_machine(tmpdir):
         arch="MIPS",
         cpu="10 MHz",
         ram="640k",
-        _path=join(tmpdir, 'asv-machine.json'))
+        _path=join(tmpdir, 'asv-machine.json'),
+    )
 
-    m = machine.Machine.load(
-        _path=join(tmpdir, 'asv-machine.json'), interactive=False)
+    m = machine.Machine.load(_path=join(tmpdir, 'asv-machine.json'), interactive=False)
 
     assert m.machine == 'orangutan'
     assert m.os == 'BeOS'
@@ -30,8 +30,7 @@ def test_machine_defaults(tmpdir):
     tmpdir = str(tmpdir)
 
     m = machine.Machine.load(
-        interactive=True,
-        use_defaults=True,
-        _path=join(tmpdir, 'asv-machine.json'))
+        interactive=True, use_defaults=True, _path=join(tmpdir, 'asv-machine.json')
+    )
 
     assert m.__dict__ == m.get_defaults()
