@@ -3,8 +3,8 @@ import datetime
 import os
 import shutil
 import subprocess
-import xml.etree.ElementTree as etree
-from os.path import abspath, dirname, join, isfile, isdir
+import xml.etree.ElementTree as ET
+from os.path import abspath, dirname, isdir, isfile, join
 
 import json5
 import pytest
@@ -35,23 +35,27 @@ def test_publish(tmpdir, example_results):
     os.makedirs(join(result_dir, 'cheetah'))
 
     # Synthesize history with two branches that both have commits
-    result_files = [fn for fn in os.listdir(join(example_results, 'cheetah'))
-                    if fn.endswith('.json') and fn != 'machine.json']
+    result_files = [
+        fn
+        for fn in os.listdir(join(example_results, 'cheetah'))
+        if fn.endswith('.json') and fn != 'machine.json'
+    ]
     result_files.sort()
     main_values = list(range(len(result_files) * 2 // 3))
     branch_values = list(range(len(main_values), len(result_files)))
-    dvcs = tools.generate_test_repo(tmpdir, main_values, 'git',
-                                    [(f'{util.git_default_branch()}~6',
-                                      'some-branch', branch_values)])
+    dvcs = tools.generate_test_repo(
+        tmpdir,
+        main_values,
+        'git',
+        [(f'{util.git_default_branch()}~6', 'some-branch', branch_values)],
+    )
 
     # Copy and modify result files, fixing commit hashes and setting result
     # dates to distinguish the two branches
     main_commits = dvcs.get_branch_hashes(f'{util.git_default_branch()}')
-    only_branch = [x for x in dvcs.get_branch_hashes('some-branch')
-                   if x not in main_commits]
+    only_branch = [x for x in dvcs.get_branch_hashes('some-branch') if x not in main_commits]
     commits = main_commits + only_branch
-    for k, item in enumerate(zip(result_files, commits)):
-        fn, commit = item
+    for fn, commit in zip(result_files, commits):
         src = join(example_results, 'cheetah', fn)
         dst = join(result_dir, 'cheetah', commit[:8] + fn[8:])
         try:
@@ -63,18 +67,22 @@ def test_publish(tmpdir, example_results):
         data['commit_hash'] = commit
         util.write_json(dst, data)
 
-    shutil.copyfile(join(example_results, 'benchmarks.json'),
-                    join(result_dir, 'benchmarks.json'))
-    shutil.copyfile(join(example_results, 'cheetah', 'machine.json'),
-                    join(result_dir, 'cheetah', 'machine.json'))
+    shutil.copyfile(join(example_results, 'benchmarks.json'), join(result_dir, 'benchmarks.json'))
+    shutil.copyfile(
+        join(example_results, 'cheetah', 'machine.json'),
+        join(result_dir, 'cheetah', 'machine.json'),
+    )
 
     # Publish the synthesized data
     conf = config.Config.from_json(
-        {'benchmark_dir': BENCHMARK_DIR,
-         'results_dir': result_dir,
-         'html_dir': join(tmpdir, 'html'),
-         'repo': dvcs.path,
-         'project': 'asv'})
+        {
+            'benchmark_dir': BENCHMARK_DIR,
+            'results_dir': result_dir,
+            'html_dir': join(tmpdir, 'html'),
+            'repo': dvcs.path,
+            'project': 'asv',
+        }
+    )
 
     tools.run_asv_with_conf(conf, 'publish')
 
@@ -83,21 +91,32 @@ def test_publish(tmpdir, example_results):
     assert isfile(join(tmpdir, 'html', 'index.json'))
     assert isfile(join(tmpdir, 'html', 'asv.js'))
     assert isfile(join(tmpdir, 'html', 'asv.css'))
-    assert not isdir(join(tmpdir, 'html', 'graphs', 'Cython', 'arch-x86_64',
-                          'branch-some-branch'))
-    assert not isdir(join(tmpdir, 'html', 'graphs', 'Cython-null', 'arch-x86_64',
-                          'branch-some-branch'))
+    assert not isdir(join(tmpdir, 'html', 'graphs', 'Cython', 'arch-x86_64', 'branch-some-branch'))
+    assert not isdir(
+        join(tmpdir, 'html', 'graphs', 'Cython-null', 'arch-x86_64', 'branch-some-branch')
+    )
     index = util.load_json(join(tmpdir, 'html', 'index.json'))
     assert index['params']['branch'] == [f'{util.git_default_branch()}']
 
     repo = get_repo(conf)
-    revision_to_hash = dict((r, h) for h, r in repo.get_revisions(commits).items())
+    revision_to_hash = {r: h for h, r in repo.get_revisions(commits).items()}
 
     def check_file(branch, cython):
-        fn = join(tmpdir, 'html', 'graphs', cython, 'arch-x86_64', 'branch-' + branch,
-                  'cpu-Intel(R) Core(TM) i5-2520M CPU @ 2.50GHz (4 cores)',
-                  'machine-cheetah', 'numpy-1.8', 'os-Linux (Fedora 20)', 'python-2.7', 'ram-8.2G',
-                  'time_coordinates.time_latitude.json')
+        fn = join(
+            tmpdir,
+            'html',
+            'graphs',
+            cython,
+            'arch-x86_64',
+            'branch-' + branch,
+            'cpu-Intel(R) Core(TM) i5-2520M CPU @ 2.50GHz (4 cores)',
+            'machine-cheetah',
+            'numpy-1.8',
+            'os-Linux (Fedora 20)',
+            'python-2.7',
+            'ram-8.2G',
+            'time_coordinates.time_latitude.json',
+        )
         data = util.load_json(fn)
         data_commits = [revision_to_hash[x[0]] for x in data]
         if branch == f'{util.git_default_branch()}':
@@ -129,17 +148,21 @@ def test_publish(tmpdir, example_results):
     assert index['params']['Cython'] == ['', None]
     assert index['params']['ram'] == ['8.2G', 8804682956.8]
 
-    expected_graph_list = [{'Cython': cython, 'arch': 'x86_64',
-                            'branch': branch,
-                            'cpu': 'Intel(R) Core(TM) i5-2520M CPU @ 2.50GHz (4 cores)',
-                            'machine': 'cheetah',
-                            'numpy': '1.8',
-                            'os': 'Linux (Fedora 20)',
-                            'python': '2.7',
-                            'ram': '8.2G'}
-                           for cython in ["",
-                                          None] for branch in [f"{util.git_default_branch()}",
-                                                               "some-branch"]]
+    expected_graph_list = [
+        {
+            'Cython': cython,
+            'arch': 'x86_64',
+            'branch': branch,
+            'cpu': 'Intel(R) Core(TM) i5-2520M CPU @ 2.50GHz (4 cores)',
+            'machine': 'cheetah',
+            'numpy': '1.8',
+            'os': 'Linux (Fedora 20)',
+            'python': '2.7',
+            'ram': '8.2G',
+        }
+        for cython in ["", None]
+        for branch in [f"{util.git_default_branch()}", "some-branch"]
+    ]
     d = dict(expected_graph_list[0])
     d['ram'] = 8804682956.8
     expected_graph_list.append(d)
@@ -160,9 +183,8 @@ def _graph_path(dvcs_type):
 def test_publish_range_spec(generate_result_dir):
     conf, repo, commits = generate_result_dir(5 * [1])
     for range_spec, expected in (
-        ([commits[0], commits[-1]], set([commits[0], commits[-1]])),
-        ('HEAD~2..HEAD' if repo.dvcs == 'git' else '.~1:',
-            set(commits[-2:])),
+        ([commits[0], commits[-1]], {commits[0], commits[-1]}),
+        ('HEAD~2..HEAD' if repo.dvcs == 'git' else '.~1:', set(commits[-2:])),
     ):
         tools.run_asv_with_conf(conf, "publish", range_spec)
         data = util.load_json(join(conf.html_dir, 'index.json'))
@@ -174,9 +196,11 @@ def test_regression_simple(generate_result_dir):
     conf, repo, commits = generate_result_dir(5 * [1] + 5 * [10])
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {"regressions": [["time_func", _graph_path(repo.dvcs), {}, None, 10.0, 1.0,
-                [[None, 5, 1.0, 10.0]]
-    ]]}
+    expected = {
+        "regressions": [
+            ["time_func", _graph_path(repo.dvcs), {}, None, 10.0, 1.0, [[None, 5, 1.0, 10.0]]]
+        ]
+    }
     assert regressions == expected
 
 
@@ -184,9 +208,19 @@ def test_regression_range(generate_result_dir):
     conf, repo, commits = generate_result_dir(5 * [1] + 6 * [10], commits_without_result=[5])
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {"regressions": [["time_func", _graph_path(repo.dvcs), {}, None, 10.0, 1.0,
-                                 [[4, 6, 1.0, 10.0]], ]]
-                }
+    expected = {
+        "regressions": [
+            [
+                "time_func",
+                _graph_path(repo.dvcs),
+                {},
+                None,
+                10.0,
+                1.0,
+                [[4, 6, 1.0, 10.0]],
+            ]
+        ]
+    }
     assert regressions == expected
 
 
@@ -202,9 +236,19 @@ def test_regression_double(generate_result_dir):
     conf, repo, commits = generate_result_dir(5 * [1] + 5 * [10] + 5 * [15])
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {"regressions": [["time_func", _graph_path(repo.dvcs), {}, None, 15.0, 1.0,
+    expected = {
+        "regressions": [
+            [
+                "time_func",
+                _graph_path(repo.dvcs),
+                {},
+                None,
+                15.0,
+                1.0,
                 [[None, 5, 1.0, 10.0], [None, 10, 10.0, 15.0]],
-    ]]}
+            ]
+        ]
+    }
     assert regressions == expected
 
 
@@ -227,9 +271,11 @@ def test_regression_first_commits(generate_result_dir):
     conf.regressions_first_commits = {"^time_*": commits[2]}
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {"regressions": [["time_func", _graph_path(repo.dvcs), {}, None, 10.0, 1.0,
-                                 [[None, 5, 1.0, 10.0]]]]
-                }
+    expected = {
+        "regressions": [
+            ["time_func", _graph_path(repo.dvcs), {}, None, 10.0, 1.0, [[None, 5, 1.0, 10.0]]]
+        ]
+    }
     assert regressions == expected
 
 
@@ -239,26 +285,38 @@ def test_regression_parameterized(generate_result_dir):
     conf, repo, commits = generate_result_dir(5 * [before] + 5 * [after])
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {'regressions': [[
-        'time_func(a)',
-        _graph_path(repo.dvcs),
-        {},
-        0,
-        6.0, 5.0, [[None, 5, 5.0, 6.0]],
-    ], [
-        'time_func(c)',
-        _graph_path(repo.dvcs),
-        {},
-        2,
-        10.0, 1.0, [[None, 5, 1.0, 10.0]],
-    ]]}
+    expected = {
+        'regressions': [
+            [
+                'time_func(a)',
+                _graph_path(repo.dvcs),
+                {},
+                0,
+                6.0,
+                5.0,
+                [[None, 5, 5.0, 6.0]],
+            ],
+            [
+                'time_func(c)',
+                _graph_path(repo.dvcs),
+                {},
+                2,
+                10.0,
+                1.0,
+                [[None, 5, 1.0, 10.0]],
+            ],
+        ]
+    }
     assert regressions == expected
 
 
-@pytest.mark.parametrize("dvcs_type", [
-    "git",
-    pytest.param("hg", marks=pytest.mark.skipif(hglib is None, reason="needs hglib")),
-])
+@pytest.mark.parametrize(
+    "dvcs_type",
+    [
+        "git",
+        pytest.param("hg", marks=pytest.mark.skipif(hglib is None, reason="needs hglib")),
+    ],
+)
 def test_regression_multiple_branches(dvcs_type, tmpdir):
     tmpdir = str(tmpdir)
     if dvcs_type == "git":
@@ -266,17 +324,23 @@ def test_regression_multiple_branches(dvcs_type, tmpdir):
     elif dvcs_type == "hg":
         main = "default"
     dvcs = tools.generate_repo_from_ops(
-        tmpdir, dvcs_type, [
+        tmpdir,
+        dvcs_type,
+        [
             ("commit", 1),
             ("checkout", "stable", main),
             ("commit", 1),
             ("checkout", main),
-        ] + 4 * [
+        ]
+        + 4
+        * [
             ("commit", 1),
             ("checkout", "stable"),
             ("commit", 1),
             ("checkout", main),
-        ] + 5 * [
+        ]
+        + 5
+        * [
             ("commit", 1),
             ("checkout", "stable"),
             ("commit", 2),
@@ -284,10 +348,9 @@ def test_regression_multiple_branches(dvcs_type, tmpdir):
         ],
     )
     commit_values = {}
-    branches = dict(
-        (branch, list(reversed(dvcs.get_branch_hashes(branch))))
-        for branch in (main, "stable")
-    )
+    branches = {
+        branch: list(reversed(dvcs.get_branch_hashes(branch))) for branch in (main, "stable")
+    }
     for branch, values in (
         (main, 10 * [1]),
         ("stable", 5 * [1] + 5 * [2]),
@@ -302,26 +365,39 @@ def test_regression_multiple_branches(dvcs_type, tmpdir):
     graph_path = join('graphs', 'branch-stable', 'machine-tarzan', 'time_func.json')
     # Regression occur on 5th commit of stable branch
     revision = repo.get_revisions(commit_values.keys())[branches["stable"][5]]
-    expected = {'regressions': [['time_func', graph_path, {'branch': 'stable'}, None,
-                                 2.0, 1.0, [[None, revision, 1.0, 2.0]]]]}
+    expected = {
+        'regressions': [
+            [
+                'time_func',
+                graph_path,
+                {'branch': 'stable'},
+                None,
+                2.0,
+                1.0,
+                [[None, revision, 1.0, 2.0]],
+            ]
+        ]
+    }
     assert regressions == expected
 
 
-@pytest.mark.parametrize("dvcs_type", [
-    "git",
-    pytest.param("hg", marks=pytest.mark.skipif(hglib is None, reason="needs hglib"))
-])
+@pytest.mark.parametrize(
+    "dvcs_type",
+    ["git", pytest.param("hg", marks=pytest.mark.skipif(hglib is None, reason="needs hglib"))],
+)
 def test_regression_non_monotonic(dvcs_type, tmpdir):
     tmpdir = str(tmpdir)
     now = datetime.datetime.now(datetime.timezone.utc)
 
-    dates = [now + datetime.timedelta(days=i)
-             for i in range(5)] + [now - datetime.timedelta(days=i) for i in range(5)]
+    dates = [now + datetime.timedelta(days=i) for i in range(5)] + [
+        now - datetime.timedelta(days=i) for i in range(5)
+    ]
     # last commit in the past
     dates[-1] = now - datetime.timedelta(days=1)
 
-    dvcs = tools.generate_repo_from_ops(tmpdir, dvcs_type,
-                                        [("commit", i, d) for i, d in enumerate(dates)])
+    dvcs = tools.generate_repo_from_ops(
+        tmpdir, dvcs_type, [("commit", i, d) for i, d in enumerate(dates)]
+    )
     commits = list(reversed(dvcs.get_branch_hashes()))
     commit_values = {}
     for commit, value in zip(commits, 5 * [1] + 5 * [2]):
@@ -329,8 +405,11 @@ def test_regression_non_monotonic(dvcs_type, tmpdir):
     conf = tools.generate_result_dir(tmpdir, dvcs, commit_values)
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {'regressions': [['time_func', _graph_path(dvcs_type), {}, None,
-                                 2.0, 1.0, [[None, 5, 1.0, 2.0]]]]}
+    expected = {
+        'regressions': [
+            ['time_func', _graph_path(dvcs_type), {}, None, 2.0, 1.0, [[None, 5, 1.0, 2.0]]]
+        ]
+    }
     assert regressions == expected
 
 
@@ -340,16 +419,30 @@ def test_regression_threshold(generate_result_dir):
     conf.regressions_thresholds = {'.*': 0}
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {"regressions": [["time_func", _graph_path(repo.dvcs), {}, None,
-                                 2.0, 1.0, [[None, 5, 1.0, 1.1], [None, 10, 1.1, 2.0]]]]}
+    expected = {
+        "regressions": [
+            [
+                "time_func",
+                _graph_path(repo.dvcs),
+                {},
+                None,
+                2.0,
+                1.0,
+                [[None, 5, 1.0, 1.1], [None, 10, 1.1, 2.0]],
+            ]
+        ]
+    }
 
     assert regressions == expected
 
     conf.regressions_thresholds = {'.*': 0, 'time_func.*': 0.2}
     tools.run_asv_with_conf(conf, "publish")
     regressions = util.load_json(join(conf.html_dir, "regressions.json"))
-    expected = {"regressions": [["time_func", _graph_path(repo.dvcs), {}, None, 2.0, 1.0,
-                                 [[None, 10, 1.1, 2.0]]]]}
+    expected = {
+        "regressions": [
+            ["time_func", _graph_path(repo.dvcs), {}, None, 2.0, 1.0, [[None, 10, 1.1, 2.0]]]
+        ]
+    }
 
     assert regressions == expected
 
@@ -360,7 +453,7 @@ def test_regression_atom_feed(generate_result_dir):
 
     commits = list(reversed(repo.get_branch_commits(None)))
 
-    tree = etree.parse(join(conf.html_dir, "regressions.xml"))
+    tree = ET.parse(join(conf.html_dir, "regressions.xml"))
     root = tree.getroot()
 
     assert root.tag == '{http://www.w3.org/2005/Atom}feed'
@@ -385,32 +478,34 @@ def test_regression_atom_feed(generate_result_dir):
     assert id_1.text != id_2.text
 
 
-@pytest.mark.parametrize("dvcs_type", [
-    "git",
-    pytest.param("hg", marks=pytest.mark.skipif(hglib is None, reason="needs hglib"))
-])
+@pytest.mark.parametrize(
+    "dvcs_type",
+    ["git", pytest.param("hg", marks=pytest.mark.skipif(hglib is None, reason="needs hglib"))],
+)
 def test_regression_atom_feed_update(dvcs_type, tmpdir):
     # Check that adding new commits which only change values preserves
     # feed entry ids
     tmpdir = str(tmpdir)
     values = 5 * [1] + 5 * [10] + 5 * [15.70, 15.31]
     dvcs = tools.generate_repo_from_ops(
-        tmpdir, dvcs_type, [("commit", i) for i in range(len(values))])
+        tmpdir, dvcs_type, [("commit", i) for i in range(len(values))]
+    )
     commits = list(reversed(dvcs.get_branch_hashes()))
 
     # Old results (drop last 6)
     commit_values = {}
     for commit, value in zip(commits, values[:-5]):
         commit_values[commit] = value
-    conf = tools.generate_result_dir(tmpdir, dvcs, commit_values,
-                                     updated=datetime.datetime(
-                                         1970, 1, 1,
-                                         tzinfo = datetime.timezone.utc)
-                                     )
+    conf = tools.generate_result_dir(
+        tmpdir,
+        dvcs,
+        commit_values,
+        updated=datetime.datetime(1970, 1, 1, tzinfo=datetime.timezone.utc),
+    )
 
     tools.run_asv_with_conf(conf, "publish")
 
-    old_tree = etree.parse(join(conf.html_dir, "regressions.xml"))
+    old_tree = ET.parse(join(conf.html_dir, "regressions.xml"))
 
     # New results (values change, regressing revisions stay same)
     for commit, value in zip(commits, values):
@@ -418,13 +513,16 @@ def test_regression_atom_feed_update(dvcs_type, tmpdir):
 
     shutil.rmtree(conf.results_dir)
     shutil.rmtree(conf.html_dir)
-    conf = tools.generate_result_dir(tmpdir, dvcs, commit_values,
-                                     updated=datetime.datetime(1990, 1, 1,
-                                                               tzinfo=datetime.timezone.utc))
+    conf = tools.generate_result_dir(
+        tmpdir,
+        dvcs,
+        commit_values,
+        updated=datetime.datetime(1990, 1, 1, tzinfo=datetime.timezone.utc),
+    )
 
     tools.run_asv_with_conf(conf, "publish")
 
-    new_tree = etree.parse(join(conf.html_dir, "regressions.xml"))
+    new_tree = ET.parse(join(conf.html_dir, "regressions.xml"))
 
     # Check ids didn't change
     old_root = old_tree.getroot()
@@ -435,7 +533,7 @@ def test_regression_atom_feed_update(dvcs_type, tmpdir):
 
     assert len(new_entries) == len(old_entries) == 2
 
-    for j, (a, b) in enumerate(zip(new_entries, old_entries)):
+    for a, b in zip(new_entries, old_entries):
         a_id = a.find('{http://www.w3.org/2005/Atom}id')
         b_id = b.find('{http://www.w3.org/2005/Atom}id')
         assert a_id.text == b_id.text
@@ -444,16 +542,18 @@ def test_regression_atom_feed_update(dvcs_type, tmpdir):
         b_content = b.find('{http://www.w3.org/2005/Atom}content')
         assert a_content.text != b_content.text
 
+
 @pytest.mark.skipif(tools.HAS_PYPY, reason="Flaky on pypy")
 def test_branch_name_is_also_filename(tmpdir):
     # gh-1209
     tmpdir = str(tmpdir)
-    dvcs = tools.generate_test_repo(tmpdir, list(range(10)),
-                                    dvcs_type="git",
-                                    extra_branches=[(f"{util.git_default_branch()}~4",
-                                                     "benchmarks", [11, 12, 13])])
-    subprocess.run(["asv", "quickstart", "--top-level"],
-                   cwd=dvcs.path, check=True)
+    dvcs = tools.generate_test_repo(
+        tmpdir,
+        list(range(10)),
+        dvcs_type="git",
+        extra_branches=[(f"{util.git_default_branch()}~4", "benchmarks", [11, 12, 13])],
+    )
+    subprocess.run(["asv", "quickstart", "--top-level"], cwd=dvcs.path, check=True)
     with open(f"{dvcs.path}/asv.conf.json", 'r+') as fhandle:
         conf = json5.load(fhandle)
         conf["branches"] = ["benchmarks"]
@@ -461,11 +561,8 @@ def test_branch_name_is_also_filename(tmpdir):
         fhandle.seek(0)
         json5.dump(conf, fhandle, indent=4)
         fhandle.truncate()
-    subprocess.run(["asv", "machine", "--yes"],
-                   cwd=dvcs.path, check=False)
-    subprocess.run(["asv", "run"],
-                   cwd=dvcs.path, check=False)
-    retdat = subprocess.run(["asv", "publish"], cwd=dvcs.path,
-                            capture_output=True, text=True)
+    subprocess.run(["asv", "machine", "--yes"], cwd=dvcs.path, check=False)
+    subprocess.run(["asv", "run"], cwd=dvcs.path, check=False)
+    retdat = subprocess.run(["asv", "publish"], cwd=dvcs.path, capture_output=True, text=True)
     assert "git rev-list --first-parent benchmarks" not in retdat.stderr
     assert retdat.returncode == 0
